@@ -2,9 +2,10 @@ package Module::CPANTS::Kwalitee::License;
 use warnings;
 use strict;
 use File::Spec::Functions qw(catfile);
-use Software::LicenseUtils;
+use Pod::Simple::TextContent;
+use List::MoreUtils qw(all any);
 
-our $VERSION = '0.88';
+our $VERSION = '0.89';
 
 sub order { 100 }
 
@@ -15,74 +16,42 @@ sub order { 100 }
 sub analyse {
     my $class=shift;
     my $me=shift;
-    my $distdir=$me->distdir;
 
+    main::logger(__PACKAGE__ . "::analyse called");
     # check META.yml
     my $yaml=$me->d->{meta_yml};
     $me->d->{license} = '';
     if ($yaml) {
         if ($yaml->{license} and $yaml->{license} ne 'unknown') {
             $me->d->{license_from_yaml} = $yaml->{license};
-            $me->d->{license} = $yaml->{license}.' defined in META.yml';
+            $me->d->{license} = $yaml->{license}.' defined in META.yaml';
         }
     }
-    my $files = $me->d->{files_hash};
+    my $files=$me->d->{files_array};
 
     # check if there's a LICEN[CS]E file
-    if (my ($file) = grep {exists $files->{$_}} qw/LICENCE LICENSE/) {
+    if (my ($file) = grep {/^LICEN[CS]E$/} @$files) {
         $me->d->{license} .= " defined in $file";
         $me->d->{external_license_file}=$file;
+        #$me->d->{license_from_external_license_file} = Software::LicenseUtils->licens_text(slurp());
     }
 
     # check pod
-    my %licenses;
-    foreach my $file (grep { /\.p(m|od|l)$/ } keys %$files ) {
-        my $path = catfile($distdir, $file);
-        next unless -r $path; # skip if not readable
-        open my $fh, '<', $path or next;
-        my $in_pod = 0;
-        my $pod = '';
-        my @possible_licenses;
-        my @unknown_license_texts;
-        while(<$fh>) {
-            if (/^=head\d\s+.*\b(?i:LICEN[CS]E|LICEN[CS]ING|COPYRIGHT|LEGAL)\b/) {
-                $in_pod = 1;
-                $pod = "=head1 LICENSE\n";
-            }
-            elsif (/^=(?:head\d\s+|cut)\b/) {
-                $in_pod = 0;
-                push @possible_licenses, Software::LicenseUtils->guess_license_from_pod("$pod\n\n=cut\n");
-
-                push @unknown_license_texts, $pod unless @possible_licenses;
-                $pod = '';
-            }
-            elsif ($in_pod) {
-                $pod .= $_;
-            }
-        }
-        if ($pod) {
-            push @possible_licenses, Software::LicenseUtils->guess_license_from_pod("$pod\n\n=cut\n");
-            push @unknown_license_texts, $pod unless @possible_licenses;
-        }
-        $me->d->{unknown_license_texts} = join "\n", @unknown_license_texts;
-
-        next unless @possible_licenses;
-        $me->d->{license_in_pod} = 1;
-        $me->d->{license} ||= "defined in POD ($file)";
-
-        $licenses{$_} = $file for @possible_licenses;
-        $files->{$file}{license} = join ',', @possible_licenses;
-    }
-    if (%licenses) {
-        $me->d->{licenses} = \%licenses;
-        my @possible_licenses = keys %licenses;
-        if (@possible_licenses == 1) {
-            my ($type) = @possible_licenses;
-            $me->d->{license_type} = $type;
-            $me->d->{license_file} = $licenses{$type};
+    #if ( $me->d->{licenses} ) {
+    #    $me->d->{license_in_pod} = 1;
+    #    $me->d->{license} .= " defined in POD";
+    #}
+    foreach my $file (grep { /\.p(m|od)$/ } @$files ) {
+        my $parser=Pod::Simple::TextContent->new;
+        my $out;
+        $parser->output_string($out);
+        $parser->parse_file( catfile($me->distdir,$file) );
+        if ($out=~/LICEN[CS]E/) {
+            $me->d->{license_in_pod} = 1;
+            $me->d->{license}="defined in POD ($file)";
         }
     }
-
+    
     return;
 }
 
@@ -91,30 +60,26 @@ sub analyse {
 ##################################################################
 
 sub kwalitee_indicators{
+    my @fedora_licenses = qw(perl apache artistic_2 gpl lgpl mit mozilla);
+    # based on: http://fedoraproject.org/wiki/Licensing
+    my $fedora_licenses = "Acceptable licenses: (" . join(", ", @fedora_licenses) . ")";
+
     return [
          {
-            name=>'has_human_readable_license',
+            name=>'has_humanreadable_license',
             error=>q{This distribution does not have a license defined in the documentation or in a file called LICENSE},
-            remedy=>q{Add a section called "LICENSE" to the documentation, or add a file named LICENSE to the distribution.},
+            remedy=>q{Add a section called 'LICENSE' to the documentation, or add a file named LICENSE to the distribution.},
             code=>sub {
                 my $d = shift;
                 return $d->{external_license_file} || $d->{license_in_pod} ? 1 : 0;
-            },
-            details=>sub {
-                my $d = shift;
-                return "Neither LICENSE file nor LICENSE section in pod was found.";
-            },
+            }
         },
         {
             name=>'has_separate_license_file',
             error=>q{This distribution does not have a LICENSE or LICENCE file in its root directory.},
             remedy=>q{This is not a critical issue. Currently mainly informative for the CPANTS authors. It might be removed later.},
             is_experimental=>1,
-            code=>sub { shift->{external_license_file} ? 1 : 0 },
-            details=>sub {
-                my $d = shift;
-                return "LICENSE file was found.";
-            },
+            code=>sub { shift->{external_license_file} ? 1 : 0 }
         },
 #        {
 #            name=>'has_known_license_in_external_license_file',
@@ -131,15 +96,31 @@ sub kwalitee_indicators{
             name=>'has_license_in_source_file',
             error=>q{Does not have license information in any of its source files},
             remedy=>q{Add =head1 LICENSE and the text of the license to the main module in your code.},
+            is_experimental=>1,
             code=>sub {
                 my $d = shift;
-                return $d->{license_in_pod} ? 1 : 0;
-            },
-            details=>sub {
-                my $d = shift;
-                return "LICENSE section was not found in the pod.";
-            },
+                # data collected in File.pm
+                
+                return 0 if not $d->{licenses};
+                return 1 if $d->{license_type};
+                $d->{error}{has_license_in_source_file} = "Seemingly conflicting licenses in files: "
+                    . join ", ", map {"$_ : $d->{licenses}{$_}"} keys %{ $d->{licenses} };
+                return 0;
+            }
         },
+        {
+            name=>'fits_fedora_license',
+            error=>qq{Fits the licensing requirements of Fedora ($fedora_licenses).},
+            remedy=>q{Replace the license or convince Fedora to accept this license as well.},
+            is_experimental=>1,
+            code=>sub { 
+                my $d=shift;
+                my $license = $d->{meta_yml}{license};
+                return ((defined $license and any {$license eq $_} @fedora_licenses) ? 1 : 0);
+
+            }
+        },
+ 
     ];
 }
 
