@@ -4,7 +4,7 @@ use strict;
 use File::Spec::Functions qw(catfile);
 use Array::Diff;
 
-our $VERSION = '0.88';
+our $VERSION = '0.89';
 
 sub order { 100 }
 
@@ -16,7 +16,7 @@ sub analyse {
     my $class=shift;
     my $me=shift;
     
-    my @files=@{$me->d->{files_array} || []};
+    my @files=@{$me->d->{files_array}};
     if (my $ignore = $me->d->{ignored_files_array}) {
         push @files, @$ignore;
     }
@@ -70,15 +70,9 @@ sub kwalitee_indicators {
     return [
         {
             name=>'manifest_matches_dist',
-            error=>q{MANIFEST does not match the contents of this distribution.},
-            remedy=>q{Run a proper command ("make manifest" or "./Build manifest", maybe with a force option), or use a distribution builder to generate the MANIFEST. Or update MANIFEST manually.},
+            error=>q{MANIFEST does not match the contents of this distribution. See 'error_manifest_matches_dist' in the dist view for more info.},
+            remedy=>q{Use a buildtool to generate the MANIFEST. Or update MANIFEST manually.},
             code=>sub { shift->{manifest_matches_dist} ? 1 : 0 },
-            details=>sub {
-                my $d = shift;
-                my $error = $d->{error}{manifest_matches_dist};
-                return $error unless ref $error;
-                return join "\n", @$error;
-            },
         }
     ];
 }
